@@ -19,6 +19,7 @@
 #ifndef _SIGC_SLOT_BASE_HPP_
 #define _SIGC_SLOT_BASE_HPP_
 
+#include <sigc++config.h>
 #include <sigc++/trackable.h>
 #include <sigc++/functors/functor_trait.h>
 
@@ -49,7 +50,7 @@ typedef void* (*hook)(void*);
  * slot_rep inherits trackable so that connection objects can
  * refer to the slot and are notified when the slot is destroyed.
  */
-struct slot_rep : public trackable
+struct SIGC_API slot_rep : public trackable
 {
   /* NB: Instead of slot_rep we could inherit slot_base from trackable.
    * However, a simple benchmark seems to indicate that this slows
@@ -62,12 +63,11 @@ struct slot_rep : public trackable
    */
   hook call_;
 
-  /// Callback that detaches the slot_rep object from referred trackables.
-  /* This could be a virtual function. However it would be identical to
-   * the virtual dtor. Therefore it's more efficient to have no virtual
-   * functions at all.
+  /// Callback that detaches the slot_rep object from referred trackables and destroys it.
+  /* This could be a replaced by a virtual dtor. However since this struct is
+   * crucual for the efficiency of the whole library we want to avoid this.
    */
-  hook detach_;
+  hook destroy_;
 
   /** Callback that makes a deep copy of the slot_rep object.
    * @return A deep copy of the slot_rep object.
@@ -80,17 +80,28 @@ struct slot_rep : public trackable
   /** Parent object whose callback cleanup_ is executed on notification. */
   void* parent_;
 
-  inline slot_rep(hook call__, hook detach__, hook dup__)
-    : call_(call__), detach_(detach__), dup_(dup__), cleanup_(0), parent_(0) {}
+  inline slot_rep(hook call__, hook destroy__, hook dup__)
+    : call_(call__), destroy_(destroy__), dup_(dup__), cleanup_(0), parent_(0) {}
 
   inline ~slot_rep()
-    { if (detach_) (*detach_)(this); }
+    { destroy(); }
+
+  // only MSVC needs this to guarantee that all new/delete are executed from the DLL module
+#ifdef SIGC_NEW_DELETE_IN_LIBRARY_ONLY
+  void* operator new(size_t size_);
+  void operator delete(void* p);
+#endif
+
+  /** Destroys the slot_rep object (but doesn't delete it).
+   */
+  inline void destroy()
+    { if (destroy_) (*destroy_)(this); }
 
   /** Makes a deep copy of the slot_rep object.
    * @return A deep copy of the slot_rep object.
    */
   inline slot_rep* dup() const
-    { return (slot_rep*)(*dup_)(const_cast<slot_rep*>(this)); }
+    { return reinterpret_cast<slot_rep*>((*dup_)(const_cast<slot_rep*>(this))); }
 
   /** Set the parent with a callback.
    * slots have one parent exclusively.
@@ -120,7 +131,7 @@ struct slot_rep : public trackable
  * Consequently slot_rep::notify() gets executed when the
  * trackable is destroyed or overwritten.
  */
-struct slot_do_bind
+struct SIGC_API slot_do_bind
 {
   /** The slot_rep object trackables should notify on destruction. */
   slot_rep* rep_;
@@ -138,7 +149,7 @@ struct slot_do_bind
 };
 
 /// Functor used to remove a dependency from a trackable.
-struct slot_do_unbind
+struct SIGC_API slot_do_unbind
 {
   /** The slot_rep object trackables don't need to notify on destruction any more. */
   slot_rep* rep_;
@@ -203,7 +214,7 @@ struct slot_do_unbind
  *
  * @ingroup slot
  */
-class slot_base : public functor_base
+class SIGC_API slot_base : public functor_base
 {
   typedef internal::slot_rep rep_type;
 
@@ -225,10 +236,10 @@ public:
 
   /** Tests whether a slot is null, because the default constructor was used.
    * Test a slot for null like so:
-   * <code>
+   * @code
    * if(slot)
    *  do_something()
-   * <endcode>
+   * @endcode
    */
   operator bool() const;
 
@@ -287,7 +298,9 @@ public:
    */
   void disconnect();
 
-protected:
+//The Tru64 and Solaris Forte 5.5 compilers needs this operator=() to be public. I'm not sure why, or why it needs to be protected usually. murrayc.
+//See bug #168265. 
+//protected:
   /** Overrides this slot making a copy from another slot.
    * @param src The slot from which to make a copy.
    * @return @p this.
